.. _aoa:

Anatomy Of The Application
==========================

This document is meant to give an overview of the Glances interface.

Legend:

=========== ============
``GREEN``   ``OK``
``BLUE``    ``CAREFUL``
``MAGENTA`` ``WARNING``
``RED``     ``CRITICAL``
=========== ============

.. note::
    Only stats with colored background will be shown in the alert view.

.. toctree::
   :maxdepth: 2

   header
   quicklook
   cpu
   gpu
   load
   memory
   network
   wifi
   ports
   disk
   fs
   folders
   irq
   sensors
   ps
   monitor
   amps
   logs
   docker
   actions
